/* Main API
 *
 * Juno Gi Editor
 *
 * Copyright (C) 2012 Kim Taylor <kmtaylor@gmx.com>
 *
 *	This program is free software; you can redistribute it and/or modify it
 *	under the terms of the GNU General Public License as published by the
 *	Free Software Foundation version 2 of the License.
 * 
 *	This program is distributed in the hope that it will be useful, but
 *	WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *	General Public License for more details.
 * 
 *	You should have received a copy of the GNU General Public License along
 *	with this program; if not, write to the Free Software Foundation, Inc.,
 *	675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: libgieditor.h,v 1.4 2012/06/08 08:07:55 kmtaylor Exp $
 */

#include <stdio.h>
#include <stdint.h>

extern void *__common_allocate(size_t size, char *func_name);

typedef const struct s_midi_class MidiClass;
typedef const struct s_midi_class_member *ClassMembers;

struct s_midi_class_member {
	const char	    *name;
	const uint32_t	    sysex_addr_base;
	const MidiClass	    *class;
};

struct s_midi_class {
	const char	    *name;
	const ClassMembers  members;
	const int	    size;
	const MidiClass	    **parents;
};

typedef struct s_midi_address {
	const uint32_t	    sysex_addr;
	const uint32_t	    sysex_size;
	const MidiClass	    *class;
	int		    blacklisted;
	int		    store;
} midi_address;

extern int libgieditor_init(const char *client_name);
extern int libgieditor_close(void);

extern midi_address *libgieditor_match_midi_address(uint32_t sysex_addr);

extern const char *libgieditor_get_desc(uint32_t sysex_addr);

extern uint32_t libgieditor_add_addresses(uint32_t address1,
				uint32_t address2);

extern char **libgieditor_get_parents(uint32_t sysex_addr, int *num);

extern uint32_t libgieditor_get_sysex_size(uint32_t sysex_addr);

extern uint32_t libgieditor_get_sysex_value(uint8_t *data, uint32_t size);

extern int libgieditor_listen_sysex_event(uint8_t *command_id, 
		                uint32_t *address, uint8_t **data);
